==> pleeease-3.2.2.tgz: package/README.md <==
Pleeease
========

**Process CSS with ease.**

* [Website](http://pleeease.io)
* [Documentation](http://pleeease.io/docs)
* [Interactive Demo](http://pleeease.io/play)

Pleeease is a Node.js application that easily process your CSS. It simplifies the use of preprocessors and combines them with best postprocessors. It helps create clean stylesheets, support older browsers and offers better maintenability. This means no more Compass for prefixes, no more rem mixins, and so on.

Pleeease.NEXT goes even further and allows you to use some of the future CSS features today. [Read cautionary note](http://pleeease.io/docs/#pleeease-next).

Pleeease is based on [PostCSS](https://github.com/ai/postcss) postprocessor and uses preprocessors Sass, LESS and Stylus.

[![Build Status](https://travis-ci.org/iamvdo/pleeease.svg?branch=master)](https://travis-ci.org/iamvdo/pleeease)
[![Coverage Status](https://coveralls.io/repos/iamvdo/pleeease/badge.svg?branch=coverage)](https://coveralls.io/r/iamvdo/pleeease?branch=coverage)

##Plugins
* for [less.js](https://github.com/bassjobsen/less-plugin-pleeease)
* for [Meteor](https://github.com/bassjobsen/less-pleeease)

##Workflow

* for [Gulp](https://github.com/danielhusar/gulp-pleeease)
* for [Brunch](https://github.com/iamvdo/brunch-pleeease)
* for [Grunt](https://github.com/danielhusar/grunt-pleeease)

##Contribute

* Clone repository
* Install dependencies with `npm install`
* Run tests with `npm test`
* There are also Gulp tasks: lint code, create standalone version, bump version

There is a lot of stuff to do: adding more unit tests, adding new postprocess tasks, etc.

##Licence

MIT [Vincent De Oliveira](https://github.com/iamvdo)

==> pleeease-4.0.1.tgz: package/README.md <==
Pleeease
========

**Process CSS with ease.**

* [Website](http://pleeease.io)
* [Documentation](http://pleeease.io/docs)
* [Interactive Demo](http://pleeease.io/play)

Pleeease is a Node.js application that easily process your CSS. **It combines CSS preprocessors with PostCSS plugins, like Autoprefixer, Pixrem and so on, with full sourcemaps support**. It helps create clean stylesheets, support older browsers and offers better maintenability.

In short, `Pleeease === ((Sass || LESS || Stylus) || CSS) && PostCSS`

[![Build Status](https://travis-ci.org/iamvdo/pleeease.svg?branch=master)](https://travis-ci.org/iamvdo/pleeease)
[![Coverage Status](https://coveralls.io/repos/iamvdo/pleeease/badge.svg?branch=coverage)](https://coveralls.io/r/iamvdo/pleeease?branch=coverage)

##Plugins
* for [less.js](https://github.com/bassjobsen/less-plugin-pleeease)
* for [Meteor](https://github.com/bassjobsen/less-pleeease)

##Workflow

* for [Gulp](https://github.com/danielhusar/gulp-pleeease)
* for [Brunch](https://github.com/iamvdo/brunch-pleeease)
* for [Grunt](https://github.com/danielhusar/grunt-pleeease)
* for [webpack](https://github.com/lmtm/pleeease-loader)

##Contribute

* Clone repository
* Install dependencies with `npm install`
* Run tests with `npm test`
* There are also Gulp tasks: lint code, create standalone version, bump version

There is a lot of stuff to do: adding more unit tests, adding new postprocess tasks, etc.

##Licence

MIT [Vincent De Oliveira](https://github.com/iamvdo)
